/**
 * @file
 * @author  Marius Stene <marius.stene at gmail.com>
 * @version 1.0
 *
 * @section LICENSE
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details at
 * http://www.gnu.org/copyleft/gpl.html
 *
 * @section DESCRIPTION
 * Class for doing the actual calculations, inherits QThread
 */

#ifndef CALCULATETHREAD_H
#define CALCULATETHREAD_H

#include <QThread>
#include <QString>
#include <QDebug>
#include <QFile>
#include <QMessageBox>

#include <vector>

#include "defines.h"
#include "../../Support/calculatefunctions.h"
#include "../../Support/data.h"
#include "../../Support/frictionfunctions.h"
#include "../../Support/regimetransitioninterface.h"
#include "../../Support/calculateregimeinterface.h"
#include "../../Support/pluginexception.h"


class CalculateFlowThread : public QThread
{
    Q_OBJECT
public:
    CalculateFlowThread(QWidget *parent, Data *data, FrictionFunctions *frictionFunctions, CalculateFunctions *calculateFunctions,
                        bool useMinimumHoldupCriterion, unsigned int id, double tolerance = 0.0001);
    CalculateFlowThread(QWidget *parent, Data *data, FrictionFunctions *frictionFunctions, CalculateFunctions *calculateFunctions,
                        RegimeTransitionInterface *regimeTransitionPlugin,
                        unsigned int id, double tolerance = 0.0001);
    ~CalculateFlowThread();
    double diameterGas();
    double x();
    double y();
    double holdup();
    double alpha();
    double dpdx();

protected:
    void run();

private:
    QWidget *_parent;
    Data *_data;
    FrictionFunctions *_frictionFunctions;
    RegimeTransitionInterface *_regimeTransitionPlugin;
    CalculateFunctions *_calculateFunctions;
    double _diameterGas;
    double _holdup;
    double _alpha;
    double _dpdx;
    double _y;
    bool _useMinimumHoldupCriterion;
    unsigned int _resolution;
    unsigned int _id;
    double _tolerance;
signals:
    void simulationError(QString errorMsg);
};

#endif // CALCULATETHREAD_H


