/**
 * @file
 * @author  Marius Stene <marius.stene at gmail.com>
 * @version 1.0
 *
 * @section LICENSE
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details at
 * http://www.gnu.org/copyleft/gpl.html
 *
 * @section DESCRIPTION
 * Class for storing and retrieving simulation data as csv files
 */

#ifndef SIMULATIONSTORAGE_H
#define SIMULATIONSTORAGE_H

#include <QString>
#include <QStringList>
#include <QVariant>
#include <QFile>
#include <QDir>
#include <QTextStream>
#include <QDebug>

#include "../../Support/data.h"

#include <vector>

/**  @brief Class for storing and retrieving simulation data as csv files */
class SimulationStorage
{
public:
    SimulationStorage(simulationtype_t simulationType, int simulationID, QDir folderPath, const Data *data);
    ~SimulationStorage();

    bool addData(QString dataName, std::vector<double> simulationData);
    void store(bool flow = true);

    static void listSimulationParameters(simulationtype_t simulationType, int idStart, int idEnd, QDir folderPath, std::vector<int> &ids,
                                         std::vector<QString> &regimeNames,
                                         std::vector<QString> &variableNames, std::vector<double> &variablesMin, std::vector<double> &variablesMax,
                                         std::vector<double> &Usgs, std::vector<double> &Usls, std::vector<double> &angles,
                                         std::vector<double> &diameters, std::vector<double> &roughnesses);
    static bool loadSimulation(simulationtype_t simulationType, int simulationID, QDir folderPath, std::vector<QString> &dataNames,
                               std::vector<std::vector<double> > &simulationData);
    static bool deleteSimulation(simulationtype_t simulationType, int simulationID, QDir folderPath);
    static Data * loadSimulationParameters(simulationtype_t simulationType, int simulationID, QDir folderPath);

    static QString fileNamePrefix(simulationtype_t simulationType);

private:
    simulationtype_t _simulationType;
    int _simulationID;
    QString _fileName;
    QDir _folderPath;
    const Data *_data;
    unsigned int _numData;
    int _lengthData;
    std::vector<std::vector<double> > _simulationData;
    std::vector<QString> _dataName;
};

#endif // SIMULATIONSTORAGE_H
