/**
 * @file
 * @author  Marius Stene <marius.stene at gmail.com>
 * @version 1.0
 *
 * @section LICENSE
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details at
 * http://www.gnu.org/copyleft/gpl.html
 *
 * @section DESCRIPTION
 * Widget class which adds a XYPlot together with buttons for manipulating plot
 */

#ifndef XYPLOTAREA_H
#define XYPLOTAREA_H

#include <QWidget>
#include <QVBoxLayout>
#include <QHBoxLayout>
#include <QPushButton>
#include <QRadioButton>
#include <QString>
#include <QGroupBox>
#include <QFileDialog>
#include <QMessageBox>
#include <QLabel>
#include <QSettings>
#include <QMenu>
#include <QPixmap>
#include <QLineEdit>
#include <QPainter>
#include <QtSvg>

#include <qwt_scale_engine.h>
#include <qwt_plot_printfilter.h>
#include <qwt_plot_zoomer.h>

#include "defines.h"
#include "xyplot.h"

class XYPlotArea : public QWidget
{
    Q_OBJECT
public:
    XYPlotArea(QWidget *parent, QString title, QString xAxisLabel = "", QString yAxisLabel = "");
    XYPlot *Plot();

private:
    void saveSettings(QString folderPathSave = "");
    XYPlot *plot;
    QLineEdit *lineEditXSize;
    QLineEdit *lineEditYSize;

private slots:
    void on_radioButtonYLog_clicked();
    void on_radioButtonYLin_clicked();
    void on_radioButtonXLog_clicked();
    void on_radioButtonXLin_clicked();
    void on_radioButtonLegendRight_clicked();
    void on_radioButtonLegendBottom_clicked();
    void on_menuActionSaveAsPng_triggered();
    void on_menuActionSaveAsSvg_triggered();
};
#endif // XYPLOTAREA_H
