/**
 * @file
 * @author  Marius Stene <marius.stene at gmail.com>
 * @version 1.0
 *
 * @section LICENSE
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * @section DESCRIPTION
 * Class which handles pointers to regime calculation plugins
 * designed for being passing as argument to calculation functions
 */

#ifndef CALCULATEFUNCTIONS_H
#define CALCULATEFUNCTIONS_H

#include "calculateregimeinterface.h"

/** @brief Class which handles pointers to regime calculation plugins designed for being passing as argument to calculation functions */
class CalculateFunctions {
public:
    inline CalculateFunctions() { _pluginAnnular = NULL; _pluginDispersed = NULL;  _pluginStratified = NULL; _pluginSlug = NULL;
                        _enabledAnnular = true; _enabledDispersed = true; _enabledStratified = true; _enabledSlug = true; };

   /** Set the plugin used to calculate annular flow */
   inline void setPluginAnnular(CalculateRegimeInterface *pluginAnnular) { _pluginAnnular = pluginAnnular; };
   inline void setPluginDispersed(CalculateRegimeInterface *pluginDispersed) { _pluginDispersed = pluginDispersed; };
   inline void setPluginStratified(CalculateRegimeInterface *pluginStratified) { _pluginStratified = pluginStratified; };
   inline void setPluginSlug(CalculateRegimeInterface *pluginSlug) { _pluginSlug = pluginSlug; };

   inline void setEnabledAnnular(bool enabled) { _enabledAnnular = enabled; };
   inline void setEnabledDispersed(bool enabled) { _enabledDispersed = enabled; };
   inline void setEnabledStratified(bool enabled) { _enabledStratified = enabled; };
   inline void setEnabledSlug(bool enabled) { _enabledSlug = enabled; };

   /** Returns CalculateRegimeInterface pointer to plugin calculating annular flow*/
   inline CalculateRegimeInterface *  pluginAnnular() { return _pluginAnnular; };
   inline CalculateRegimeInterface *  pluginDispersed() { return _pluginDispersed; };
   inline CalculateRegimeInterface *  pluginStratified() { return _pluginStratified; };
   inline CalculateRegimeInterface *  pluginSlug() { return _pluginSlug; };

   inline bool isEnabledAnnular() { return _enabledAnnular; };
   inline bool isEnabledDispersed() { return _enabledDispersed; };
   inline bool isEnabledStratified() { return _enabledStratified; };
   inline bool isEnabledSlug() { return _enabledSlug; };

   inline bool isDefined() { if (_pluginAnnular != NULL && _pluginDispersed != NULL && _pluginStratified != NULL && _pluginSlug != NULL) { return true; } return false; };

private:
   CalculateRegimeInterface *_pluginAnnular;
   CalculateRegimeInterface *_pluginDispersed;
   CalculateRegimeInterface *_pluginStratified;
   CalculateRegimeInterface *_pluginSlug;

   bool _enabledAnnular;
   bool _enabledDispersed;
   bool _enabledStratified;
   bool _enabledSlug;
};

#endif // FRICTIONFUNCTIONS_H
