/**
 * @file
 * @author  Marius Stene <marius.stene at gmail.com>
 * @version 1.0
 *
 * @section LICENSE
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * @section DESCRIPTION
 * Plugin interface for the creation of regime calculation plugins
 */
#ifndef CALCULATEREGIMEINTERFACE_H
#define CALCULATEREGIMEINTERFACE_H

#include <QString>
#include <QList>
#include <QPair>

#include "plugininterface.h"
#include "frictionfunctions.h"
#include "data.h"

/** @brief Plugin interface for the creation of regime calculation plugins. These plugins are to be used as the base calculation method for a specific regime. E.g. slug */
class CalculateRegimeInterface : public PluginInterface
{
public:
        virtual ~CalculateRegimeInterface() {};

        virtual double calculateAlpha(Data *data, FrictionFunctions *frictionFunctions, double tolerance) = 0;
        virtual QList<QPair<QString, double> > calculate(Data *data, FrictionFunctions *frictionFunctions, double tolerance) = 0;
        virtual double calculatePressureDrop(Data *data, FrictionFunctions *frictionFunctions, double tolerance) = 0;


        virtual bool isAnnular() const = 0;
        virtual bool isStratified() const = 0;
        virtual bool isDispersed() const = 0;
        virtual bool isSlug() const = 0;

        virtual QString pluginName() const = 0;
};

Q_DECLARE_INTERFACE(CalculateRegimeInterface, "com.MariusStene.MultiPhase.CalculateRegimeInterface/1.0");

#endif // CALCULATEREGIMEINTERFACE_H
