/**
 * @file
 * @author  Marius Stene <marius.stene at gmail.com>
 * @version 1.0
 *
 * @section LICENSE
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * @section DESCRIPTION
 * Class which includes general functions which are of ues to all regime calculations
 */

#ifndef CALCULATEREGIMESHARED_H
#define CALCULATEREGIMESHARED_H

#include <QObject>
#include <QString>
#include <QtPlugin>
#include <QDebug>
#include <math.h>

#include "data.h"
#include "frictionfunctions.h"

class CalculateRegimeShared
{
public:
    CalculateRegimeShared();
    ~CalculateRegimeShared();
    static double bisectvoid(Data *data, FrictionFunctions *frictionFunctions,
                            double (*evalFunction)(Data*, FrictionFunctions*, double variable, double *args, int nArg),
                            double *args, int nArg, double tolerance, double x);
    static double reynolds(double density, double hdiameter, double velocity, double viscosity);
    static double hydraulicDiameter(double alpha, double area, double surface);
    static double relativeVelocityRisingBubbles(double alpha, double surfaceTension, double densityLiquid, double densityGas, double angle);
};

#endif // CALCULATEREGIMESHARED_H
