/*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 2.1 of the License, or (at your option) any later version.
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* Copyright (C) 2010 Marius Stene (marius.stene at gmail dot com)
*
*/

#include "data.h"

/*! @class Data
 *  @brief Class which handles the data storage
 */

Data::Data()
{
    _variable = NULL;
    _alpha = 0;
    _angle = 0;
    _viscosityLiquid = 0;
    _viscosityGas = 0;
    _densityLiquid = 0;
    _densityGas = 0;
    _pressureGas = 0;
    _temperatureGas = 0;
    _surfaceTension = 0;
    _Usl = 0;
    _Usg = 0;
    _diameter = 0;
    _roughness = 0;
    _variableMin = 0;
    _variableMax = 0;
    _variableType = VARIABLE_USG;
    _variableName = UsgName();
    _regimeType = REGIME_ANNULAR;
    _regimeName = "Annular";
    _regimeTransitionName = "";
}
/*
Data::Data(Data &copyData)
{
    _variable = NULL;
    setAlpha(copyData.alpha());
}
*/
Data::Data(const Data *copyData)
{
    setAlpha(copyData->alpha());
    setAngle(copyData->angle());
    setViscosityLiquid(copyData->viscosityLiquid());
    setViscosityGas(copyData->viscosityGas());
    setDensityLiquid(copyData->densityLiquid());
    setDensityGas(copyData->densityGas());
    setPressureGas(copyData->pressureGas());
    setTemperatureGas(copyData->temperatureGas());
    setSurfaceTension(copyData->surfaceTension());
    setUsl(copyData->Usl());
    setUsg(copyData->Usg());
    setDiameter(copyData->diameter());
    setRoughness(copyData->roughness());
    setVariableType(copyData->variableType());
    setVariable(copyData->variable());
    setVariableMax(copyData->variableMax());
    setVariableMin(copyData->variableMin());
    setRegimeType(copyData->regimeType());
    setRegimeTransitionName(copyData->regimeTransitionName());
}

bool Data::equals(Data *compareWith) const
{
    if (compareWith == NULL)
        return false;
    if (alpha() != compareWith->alpha())
        return false;
    if (angle() != compareWith->angle())
        return false;
    if (viscosityLiquid() != compareWith->viscosityLiquid())
        return false;
    if (viscosityGas() != compareWith->viscosityGas())
        return false;
    if (densityLiquid() != compareWith->densityLiquid())
        return false;
    if (densityGas() != compareWith->densityGas())
        return false;
    if (pressureGas() != compareWith->pressureGas())
        return false;
    if (temperatureGas() != compareWith->temperatureGas())
        return false;
    if (surfaceTension() != compareWith->surfaceTension())
        return false;
    if (Usl() != compareWith->Usl())
        return false;
    if (Usg() != compareWith->Usg())
        return false;
    if (diameter() != compareWith->diameter())
        return false;
    if (roughness() != compareWith->roughness())
        return false;
    if (variable() != compareWith->variable())
        return false;
    if (variableMax() != compareWith->variableMax())
        return false;
    if (variableMin() != compareWith->variableMin())
        return false;
    if (regimeType() != compareWith->regimeType())
        return false;
    if (variableType() != compareWith->variableType())
        return false;
    return true;
}

double Data::reynoldsLiquid()
{
    qDebug() << "Data::reynoldsLiquid()";
    double re= densityLiquid()*abs(Ul())*hdiameterLiquid()/viscosityLiquid();
    return re;
}

void Data::setAlpha(double alpha)
{
    _alpha = alpha;
}

void Data::setVariable(double variable)
{
    *_variable = variable;
}

void Data::setAngle(double angle)
{
    _angle = angle;
}

void Data::setDensityLiquid(double densityLiquid)
{
    _densityLiquid = densityLiquid;
}

void Data::setDensityGas(double densityGas)
{
_densityGas = densityGas;
}

void Data::setViscosityLiquid(double viscosityLiquid)
{
_viscosityLiquid = viscosityLiquid;
}

void Data::setViscosityGas(double viscosityGas)
{
_viscosityGas = viscosityGas;
}

void Data::setPressureGas(double pressureGas)
{
_pressureGas = pressureGas;
}

void Data::setTemperatureGas(double temperatureGas)
{
_temperatureGas = temperatureGas;
}

void Data::setSurfaceTension(double surfaceTension)
{
_surfaceTension = surfaceTension;
}

void Data::setUsg(double Usg)
{
_Usg = Usg;
}

void Data::setDiameter(double diameter)
{
_diameter = diameter;
}

void Data::setRoughness(double roughness)
{
_roughness = roughness;
}

void Data::setVariableMin(double variableMin)
{
    _variableMin = variableMin;
}

void Data::setVariableMax(double variableMax)
{
    _variableMax = variableMax;
}

void Data::setVariableType(variable_t variableType)
{
    _variableType = variableType;
    switch (_variableType) {
        case VARIABLE_USG:
            _variable = &_Usg;
            _variableName = UsgName();
        break;
        case VARIABLE_USL:
            _variable = &_Usl;
            _variableName = UslName();
        break;
        case VARIABLE_LIQUIDDENSITY:
            _variable = &_densityLiquid;
            _variableName = densityLiquidName();
        break;
        case VARIABLE_LIQUIDVISCOSITY:
            _variable = &_viscosityLiquid;
            _variableName = viscosityLiquidName();
        break;
        case VARIABLE_GASDENSITY:
            _variable = &_densityGas;
            _variableName = densityGasName();
        break;
        case VARIABLE_GASVISCOSITY:
            _variable = &_viscosityGas;
            _variableName = viscosityGasName();
        break;
        case VARIABLE_GASTEMPERATURE:
            _variable = &_temperatureGas;
            _variableName = temperatureGasName();
        break;
        case VARIABLE_GASPRESSURE:
            _variable = &_pressureGas;
            _variableName = pressureGasName();
        break;
        case VARIABLE_SURFACETENSION:
            _variable = &_surfaceTension;
            _variableName = surfaceTensionName();
        break;
        case VARIABLE_ANGLE:
            _variable = &_angle;
            _variableName = angleName();
        break;
        case VARIABLE_DIAMETER:
            _variable = &_diameter;
            _variableName = diameterName();
        break;
        case VARIABLE_ROUGHNESS:
            _variable = &_roughness;
            _variableName = roughnessName();
        break;
        default:
            _variable = &_Usg;
            _variableName = UsgName();
        break;
    }
    _variableMax = *_variable;
    _variableMin = *_variable;
}

void Data::setRegimeType(regimetype_t regimeType)
{
    _regimeType = regimeType;
    switch (_regimeType) {
        case REGIME_ANNULAR:
            _regimeName = "Annular";
        break;
        case REGIME_DISPERSED:
            _regimeName = "Dispersed";
        break;
        case REGIME_STRATIFIED:
            _regimeName = "Statified";
        break;
        case REGIME_SLUG:
            _regimeName = "Slug";
        break;
        case REGIME_DYNAMIC_MINIMUM_HOLDUP:
            _regimeName = "Minimum Holdup";
        break;
        default:
            _regimeName = "Unsupported regime type";
        break;
    }
}

void Data::setRegimeTransitionName(QString regimeTransitionName)
{
    _regimeTransitionName = regimeTransitionName;
}

QString Data::regimeNameShort(int length) const
{
    QString a = regimeName();
    a.truncate(length);
    return a;
}

void Data::writeData(QTextStream &out, bool flow) const
{
    if (flow) {
        out << "\"RegimeType\";";
    } else {
        out << "\"Transition Criterion\";";
    }
    out << "\"VariableType\";" << "\"Variable\";" << "\"VariableMax\";" << "\"VariableMin\";" << "\"VariableName\";";
    out << "\"Usl\";" <<  "\"Usg\";" << "\"Alpha\";" << "\"Angle\";" << "\"Diameter\";" << "\"Roughness\";";
    out << "\"ViscosityGas\";" << "\"DensityGas\";" << "\"pressureGas\";" << "\"TemperatureGas\";";
    out << "\"ViscosityLiquid\";" << "\"DensityLiquid\";" <<  "\"SurfaceTension\"\n";

    if (flow) {
        out << regimeType();
    } else {
        out << regimeTransitionName();
    }
    out << ";" << variableType() << ";" << variable() << ";" << variableMax() << ";" << variableMin() << ";" << variableName() << ";";
    out << Usl() << ";" << Usg() << ";" << alpha() << ";" << angle() << ";" << diameter() << ";" << roughness() << ";";
    out << viscosityGas() << ";" << densityGas() << ";" << pressureGas() << ";" << temperatureGas() << ";";
    out << viscosityLiquid() << ";" << densityLiquid() << ";" << surfaceTension() << "\n";
}

Data * Data::readData(QString dataStream, bool flow)
{
    qDebug() << "Data::readData()";
    Data *d = new Data();
    if (dataStream.contains("\n") == true) {
        qDebug() << "dataStream.contains(\"\n\") == true, reading failed!";
        return NULL;
    }

    //Read parameter values
    QStringList qsl = dataStream.split(";");
    if (qsl.size() != 19) {
        qDebug() << "qsl.size() != 19, reading failed!";
        return NULL;
    }
    if (flow) {
        d->setRegimeType((regimetype_t)QVariant(qsl.at(0)).toInt());
    } else {
        d->setRegimeTransitionName(qsl.at(0));
    }
    d->setVariableType((variable_t)QVariant(qsl.at(1)).toInt());
    d->setVariable(QVariant(qsl.at(2)).toDouble());
    d->setVariableMax(QVariant(qsl.at(3)).toDouble());
    d->setVariableMin(QVariant(qsl.at(4)).toDouble());
    //Skip 5, it's variable name, cannot be set manually
    d->setUsl(QVariant(qsl.at(6)).toDouble());
    d->setUsg(QVariant(qsl.at(7)).toDouble());
    d->setAlpha(QVariant(qsl.at(8)).toDouble());
    d->setAngle(QVariant(qsl.at(9)).toDouble());
    d->setDiameter(QVariant(qsl.at(10)).toDouble());
    d->setRoughness(QVariant(qsl.at(11)).toDouble());
    d->setViscosityGas(QVariant(qsl.at(12)).toDouble());
    d->setDensityGas(QVariant(qsl.at(13)).toDouble());
    d->setPressureGas(QVariant(qsl.at(14)).toDouble());
    d->setTemperatureGas(QVariant(qsl.at(15)).toDouble());
    d->setViscosityLiquid(QVariant(qsl.at(16)).toDouble());
    d->setDensityLiquid(QVariant(qsl.at(17)).toDouble());
    d->setSurfaceTension(QVariant(qsl.at(18)).toDouble());

    return d;
}

QString Data::dataInformation() const
{
    QString ret = "";
    ret.append(QString("<b>%1: </b>%2<br>").arg(alphaName()).arg(alpha()));
    ret.append(QString("<b>%1: </b>%2<br>").arg(angleName()).arg(angle()));
    ret.append(QString("<b>%1: </b>%2<br>").arg(diameterName()).arg(diameter()));
    ret.append(QString("<b>%1: </b>%2<br>").arg(densityGasName()).arg(densityGas()));
    ret.append(QString("<b>%1: </b>%2<br>").arg(pressureGasName()).arg(pressureGas()));
    ret.append(QString("<b>%1: </b>%2<br>").arg(temperatureGasName()).arg(temperatureGas()));
    ret.append(QString("<b>%1: </b>%2<br>").arg(viscosityGasName()).arg(viscosityGas()));
    ret.append(QString("<b>%1: </b>%2<br>").arg(diameterName()).arg(diameter()));
    ret.append(QString("<b>%1: </b>%2<br>").arg(viscosityLiquidName()).arg(viscosityLiquid()));
    ret.append(QString("<b>%1: </b>%2<br>").arg(roughnessName()).arg(roughness()));
    ret.append(QString("<b>%1: </b>%2<br>").arg(surfaceTensionName()).arg(surfaceTension()));
    ret.append(QString("<b>%1: </b>%2<br>").arg(UsgName()).arg(Usg()));
    ret.append(QString("<b>%1: </b>%2<br>").arg(UslName()).arg(Usl()));
    ret.append(QString("<b>%1: </b>%2<br>").arg("Variable").arg(variableName()));
    ret.append(QString("<b>%1: </b>%2<br>").arg("Variable Minumum").arg(variableMin()));
    ret.append(QString("<b>%1: </b>%2<br>").arg("Variable Maximum").arg(variableMax()));
    return ret;
}

#ifndef QT_NO_DEBUG_STREAM
QDebug operator<<(QDebug dbg, const Data &d) {
    dbg.nospace() << "Data:\nalpha=" << d.alpha();
    dbg.nospace() << ", angle=" << d.angle();
    dbg.nospace() << ", viscosityLiquid=" << d.viscosityLiquid();
    dbg.nospace() << ", viscosityGas=" << d.viscosityGas();
    dbg.nospace() << ", densityLiquid=" << d.densityLiquid();
    dbg.nospace() << ", densityGas=" << d.densityGas();
    dbg.nospace() << ", temperatureGas=" << d.temperatureGas();
    dbg.nospace() << ", surfaceTension=" << d.surfaceTension();
    dbg.nospace() << ", Usl=" << d.Usl();
    dbg.nospace() << ", Usg=" << d.Usg();
    dbg.nospace() << ", diameter=" << d.diameter();
    dbg.nospace() << ", roughness=" << d.roughness();
    dbg.nospace() << ", Ul=" << d.Ul();
    dbg.nospace() << ", Ug=" << d.Ug();
    dbg.nospace() << ", area=" << d.area();
    if (d.variable() != NULL) {
        dbg.nospace() << ", variable=" << d.variable();
        dbg.nospace() << ", variableMax=" << d.variableMax();
        dbg.nospace() << ", variableMin=" << d.variableMin();
        dbg.nospace() << ", variableType=" << d.variableType();
    }
    return dbg.space();
}
#endif
