/**
 * @file
 * @author  Marius Stene <marius.stene at gmail.com>
 * @version 1.0
 *
 * @section LICENSE
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * @section DESCRIPTION
 * Class which handles pointers to friction and slip relation plugins
 * designed for being passing as argument to calculation functions
 */

#ifndef FRICTIONFUNCTIONS_H
#define FRICTIONFUNCTIONS_H

#include "frictioninterface.h"
#include "interfacefrictioninterface.h"
#include "sliprelationinterface.h"

class FrictionFunctions {
public:
   FrictionFunctions();
   bool equals(FrictionFunctions *frictionFunctions);

   /** Set the plugin used to calculate wall friction for gas phase */
   inline void setPluginWallGas(FrictionInterface *pluginWallGas) { _pluginWallGas = pluginWallGas; };
   /** Set the plugin used to calculate wall friction for liquid phase */
   inline void setPluginWallLiquid(FrictionInterface *pluginWallLiquid) { _pluginWallLiquid = pluginWallLiquid; };
   /** Set the plugin used to calculate interface friction */
   inline void setPluginInterface(InterfaceFrictionInterface *pluginInterface) { _pluginInterface = pluginInterface; };
   /** Set the plugin used to calculate dispersed */
   inline void setPluginDispersed(FrictionInterface *pluginDispersed) { _pluginDispersed = pluginDispersed; };
   /** Set the plugin used to calculate slip relation */
   inline void setPluginSlipRelation(SlipRelationInterface *pluginSlipRelation) { _pluginSlipRelation = pluginSlipRelation; };

   /** Returns FrictionInterface pointer to plugin calculating wall friction for gas phase */
   inline FrictionInterface *  pluginWallGas() { return _pluginWallGas; };
   /** Returns FrictionInterface pointer to plugin calculating wall friction for liquid phase */
   inline FrictionInterface *  pluginWallLiquid() { return _pluginWallLiquid; };
   /** Returns InterfaceFrictionInterface pointer to plugin calculating interface friction */
   inline InterfaceFrictionInterface * pluginInterface() { return _pluginInterface; };
   /** Returns FrictionInterface pointer to plugin calculating dispersed friction */
   inline FrictionInterface *  pluginDispersed() { return _pluginDispersed; };
   /** Returns SlipRelationInterface pointer to plugin calculating slip relation */
   inline SlipRelationInterface *  pluginSlipRelation() { return _pluginSlipRelation; };

private:
   FrictionInterface *_pluginWallGas;
   FrictionInterface *_pluginWallLiquid;
   InterfaceFrictionInterface *_pluginInterface;
   FrictionInterface *_pluginDispersed;
   SlipRelationInterface *_pluginSlipRelation;
};

#endif // FRICTIONFUNCTIONS_H


