/**
 * @file
 * @author  Marius Stene <marius.stene at gmail.com>
 * @version 1.0
 *
 * @section LICENSE
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * @section DESCRIPTION
 * Plugin interface for the creation of friction plugins
 */

#ifndef FRICTIONINTERFACE_H
#define FRICTIONINTERFACE_H

#include "plugininterface.h"
#include "data.h"

/** @brief Plugin interface for the creation of friction plugins */
class FrictionInterface : public PluginInterface
{
public:
        virtual ~FrictionInterface() {};

        virtual double calculateLiquidFrictionFactor(Data const &data, double reynolds, double hdiameter) const = 0;
        virtual double calculateGasFrictionFactor(Data const &data, double reynolds, double hdiameter) const = 0;
        virtual double calculateDispersedFrictionFactor(Data const &data, double alpha, double reynolds, double hdiameter, double UDisp, double viscosity) const = 0;
        virtual bool isLiquidWallFriction() const = 0;
        virtual bool isGasWallFriction() const = 0;
        virtual bool isDispersedFriction() const = 0;
};

Q_DECLARE_INTERFACE(FrictionInterface, "com.MariusStene.MultiPhase.FrictionInterface/1.0");

#endif // FRICTIONINTERFACE_H
