/**
 * @file
 * @author  Marius Stene <marius.stene at gmail.com>
 * @version 1.0
 *
 * @section LICENSE
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * @section DESCRIPTION
 * Plugin interface for the creation of interface friction plugins
 */

#ifndef INTERFACEFRICTIONINTERFACE_H
#define INTERFACEFRICTIONINTERFACE_H

#include "plugininterface.h"
#include "data.h"

/** @brief Plugin interface for the creation of interface friction plugins */
class InterfaceFrictionInterface : public PluginInterface
{
public:
        virtual ~InterfaceFrictionInterface() {};

        virtual double calculateFrictionFactor(Data const &data, double alpha,
                       double reynoldsGas,double hdiameterGas,
                       double thicknessFilm, double frictionFactorGas) const = 0;
        virtual bool isInterfaceFriction() const = 0;
};

Q_DECLARE_INTERFACE(InterfaceFrictionInterface, "com.MariusStene.MultiPhase.InterfaceFrictionInterface/1.0");

#endif // INTERFACEFRICTIONINTERFACE_H
