/**
 * @file
 * @author  Marius Stene <marius.stene at gmail.com>
 * @version 1.0
 *
 * @section LICENSE
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * @section DESCRIPTION
 * Plugin interface for the creation of regime transition plugins
 */
#ifndef REGIMETRANSITIONINTERFACE_H
#define REGIMETRANSITIONINTERFACE_H

#include "plugininterface.h"
#include "calculatefunctions.h"
#include "data.h"

/** @brief Plugin interface for the creation of regime transition plugins. These plugins can be used to find the transition point in a Usg/Usl graph between different multiphase flow regimes */
class RegimeTransitionInterface : public PluginInterface
{
public:
        virtual ~RegimeTransitionInterface() {};
        virtual double calculateRegimeTransition(Data *data, FrictionFunctions *frictionFunctions, CalculateFunctions *calculateFunctions, double tolerance, double Usg) = 0;
        virtual regimetype_t calculateRegime(Data *data, FrictionFunctions *frictionFunctions, CalculateFunctions *calculateFunctions, double tolerance, double Usg, double Usl) = 0;
        virtual QString transitionDescription() const = 0;
        virtual QString tooltip() const = 0;
        virtual QString statustip() const = 0;
        virtual bool transitionAnnular() const = 0;
        virtual bool transitionStratified() const = 0;
        virtual bool transitionDispersed() const = 0;
        virtual bool transitionSlug() const = 0;
};

Q_DECLARE_INTERFACE(RegimeTransitionInterface, "com.MariusStene.MultiPhase.RegimeTransitionInterface/1.0");

#endif // REGIMETRANSITIONINTERFACE_H
