/**
 * @file
 * @author  Marius Stene <marius.stene at gmail.com>
 * @version 1.0
 *
 * @section LICENSE
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * @section DESCRIPTION
 * Plugin interface for the creation of slip relation plugins
 */

#ifndef SLIPRELATIONINTERFACE_H
#define SLIPRELATIONINTERFACE_H

#include "plugininterface.h"
#include "data.h"

class SlipRelationInterface : public PluginInterface
{
public:
        virtual ~SlipRelationInterface() {};

        virtual double calculateLiquidVelocity(Data const &data, double Usl, double Usg, double alpha) const = 0;
        virtual double calculateGasVelocity(Data const &data, double UlDisp, double alpha) const = 0;
        virtual double calculateAlpha(Data const &data, double alpha, double Usl, double Usg) const = 0;
        virtual bool isSlipRelationFriction() const = 0;
};

Q_DECLARE_INTERFACE(SlipRelationInterface, "com.MariusStene.MultiPhase.SlipRelationInterface/1.0");

#endif // SLIPRELATIONINTERFACE_H
