/*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License as
* published by the Free Software Foundation; either version 2 of
* the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* General Public License for more details at
* http://www.gnu.org/copyleft/gpl.html
*
* Author: Marius Stene
* Email: marius.stene at gmail dot com
*
*/

#include "barneabrauner.h"

BarneaBrauner::BarneaBrauner()
{
qDebug() << "BarneaBrauner::BarneaBrauner()";
}

BarneaBrauner::~BarneaBrauner()
{
qDebug() << "BarneaBrauner::~BarneaBrauner()";
}

double BarneaBrauner::calculateRegimeTransition(Data *data, FrictionFunctions *frictionFunctions, CalculateFunctions *calculateFunctions, double tolerance, double Usg)
{
    qDebug() << "BarneaBrauner::calculateRegimeTransition()";
    double lowerbound = 0.0;
    double higherbound = 100*Usg;
    double alphaSlug;
    double UslTemp;
    data->setVariable(Usg);
    while ((higherbound - lowerbound) > tolerance) {
        UslTemp = 0.5*(lowerbound+higherbound);
        data->setUsl(UslTemp);
        alphaSlug = calculateFunctions->pluginSlug()->calculateAlpha(data, frictionFunctions, tolerance);
        double holdup = 1-alphaSlug;
        qWarning() << "WELCOMEHERE holdup:" << holdup << " lowerbound:" << lowerbound << " higherbound:" << higherbound << " Usl:" << data->Usl() << " Usg:" << data->Usg();
        if (holdup < 0.24) {
            //Annular flow
            lowerbound = UslTemp;
        } else {
            higherbound = UslTemp;
        }
    }
    UslTemp = 0.5*(lowerbound+higherbound);
    return UslTemp;
}

regimetype_t BarneaBrauner::calculateRegime(Data *data, FrictionFunctions *frictionFunctions, CalculateFunctions *calculateFunctions, double tolerance, double Usg, double Usl)
{
    double transitionUsl = calculateRegimeTransition(data, frictionFunctions, calculateFunctions, tolerance, Usg);
    if (transitionUsl > Usl) {
        return REGIME_ANNULAR;
    } else {
        return REGIME_SLUG;
    }
}

QString BarneaBrauner::pluginName() const
{
    qDebug() << "BarneaBrauner::pluginName()";
    return QString("B&arnea Brauner");
}

QString BarneaBrauner::transitionDescription() const
{
    qDebug() << "BarneaBrauner::transitionDescription()";
    return QString("Annular - Slug");
}

QString BarneaBrauner::tooltip() const
{
    return QString("Barnea Brauner places the regime transition at Holdup = 0.24 because of the spontaneous blockage mechanism. \n\nD. Barnea, A unified model for predicting flow-pattern transitions for the whole range of pipe inclinations, International Journal of Multiphase Flow, Volume 13, Issue 1, January-February 1987");
}

QString BarneaBrauner::statustip() const
{
    return QString("Barnea Brauner places the regime transition at Holdup = 0.24");
}

bool BarneaBrauner::transitionAnnular() const
{
    return true;
}

bool BarneaBrauner::transitionStratified() const
{
    return false;
}

bool BarneaBrauner::transitionDispersed() const
{
    return false;
}

bool BarneaBrauner::transitionSlug() const
{
    return true;
}

Q_EXPORT_PLUGIN2(../../../application/MultiPhase/debug/lib/regimetransition/barneabrauner, BarneaBrauner);
