/*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License as
* published by the Free Software Foundation; either version 2 of
* the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* General Public License for more details at
* http://www.gnu.org/copyleft/gpl.html
*
* Author: Marius Stene
* Email: marius.stene at gmail dot com
*
*/

#include "bendiksenespedal.h"

BendiksenEspedal::BendiksenEspedal()
{
qDebug() << "BendiksenEspedal::BendiksenEspedal()";
}

BendiksenEspedal::~BendiksenEspedal()
{
qDebug() << "BendiksenEspedal::~BendiksenEspedal()";
}

double BendiksenEspedal::calculateRegimeTransition(Data *data, FrictionFunctions *frictionFunctions, CalculateFunctions *calculateFunctions, double tolerance, double Usg)
{
    qWarning() << "BendiksenEspedal::calculateRegimeTransition()" << data;
    double lowerbound = 0.0;
    double higherbound = 100*Usg;
    double alphaStrat;
    double alphaSlug;
    double UslTemp;
    data->setVariable(Usg);
    while ((higherbound - lowerbound) > tolerance) {
        UslTemp = 0.5*(lowerbound+higherbound);
        data->setUsl(UslTemp);
        alphaStrat = calculateFunctions->pluginStratified()->calculateAlpha(data, frictionFunctions, tolerance);
        alphaSlug = calculateFunctions->pluginSlug()->calculateAlpha(data, frictionFunctions, tolerance);

        qDebug() << "alphaStrat" << alphaStrat << " alphaSlug " << alphaSlug;
        if (alphaStrat > alphaSlug) {
            lowerbound = UslTemp;
        } else {
            higherbound = UslTemp;
        }
        qWarning() << "alphaStrat = " << alphaStrat << ", alphaSlug = " << alphaSlug << ", UslTemp = " << UslTemp;
    }
    qDebug() << "qwertyaa" << "alphaStrat" << alphaStrat << " alphaSlug " << alphaSlug << "Usl" << UslTemp << "Usg" << Usg;
    UslTemp= 0.5*(lowerbound+higherbound);
    return UslTemp;
}

regimetype_t BendiksenEspedal::calculateRegime(Data *data, FrictionFunctions *frictionFunctions, CalculateFunctions *calculateFunctions, double tolerance, double Usg, double Usl)
{
    double transitionUsl = calculateRegimeTransition(data, frictionFunctions, calculateFunctions, tolerance, Usg);
    if (transitionUsl > Usl) {
        return REGIME_STRATIFIED;
    } else {
        return REGIME_SLUG;
    }
}

QString BendiksenEspedal::pluginName() const
{
    qDebug() << "BendiksenEspedal::pluginName()";
    return QString("&Bendiksen Espedal");
}

QString BendiksenEspedal::transitionDescription() const
{
    qDebug() << "BendiksenEspedal::transitionDescription()";
    return QString("Stratified - Slug");
}

QString BendiksenEspedal::tooltip() const
{
    return QString("Bendiksen Espedal places the regime transition where holdup for stratified flow equals holdup for slug flow");
}

QString BendiksenEspedal::statustip() const
{
    return QString("Bendiksen Espedal places the regime transition where holdup for stratified flow equals holdup for slug flow");
}

bool BendiksenEspedal::transitionAnnular() const
{
    return false;
}

bool BendiksenEspedal::transitionStratified() const
{
    return true;
}

bool BendiksenEspedal::transitionDispersed() const
{
    return false;
}

bool BendiksenEspedal::transitionSlug() const
{
    return true;
}

Q_EXPORT_PLUGIN2(../../../application/MultiPhase/debug/lib/regimetransition/bendiksenespedal, BendiksenEspedal);
