/*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License as
* published by the Free Software Foundation; either version 2 of
* the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* General Public License for more details at
* http://www.gnu.org/copyleft/gpl.html
*
* Author: Marius Stene
* Email: marius.stene at gmail dot com
*
*/

#include "colebrook.h"


Colebrook::Colebrook()
{
    qDebug() << "Colebrook::Colebrook()";
}

Colebrook::~Colebrook()
{
    qDebug() << "Colebrook::~Colebrook()";
}

double Colebrook::calculateLiquidFrictionFactor(Data const &data, double reynolds, double hdiameter) const
{
    qDebug() << "Colebrook::calculateLiquidFrictionFactor()";
        qDebug() << "reynolds =" << reynolds << ", data.roughness() =" << data.roughness() << ", hdiameter =" << hdiameter;
    double re = pow(-1 / (2 * log10((data.roughness()/hdiameter)/3.7065 - (5.0272/reynolds) * log10((data.roughness()/hdiameter)/3.827 - (4.467/reynolds) * log10(pow((data.roughness()/hdiameter)/7.7918, 0.9924) + (5.3326/pow(208.815+reynolds, 0.9345)))))), 2);
    qDebug() << "returning =" << re;
    return re;
}

double Colebrook::calculateGasFrictionFactor(Data const &data, double reynolds, double hdiameter) const
{
    qDebug() << "Colebrook::calculateGasFrictionFactor()";
    qDebug() << "reynolds =" << reynolds << ", data.roughness() =" << data.roughness() << ", hdiameter =" << hdiameter;
    double re = pow(-1 / (2 * log10((data.roughness()/hdiameter)/3.7065 - (5.0272/reynolds) * log10((data.roughness()/hdiameter)/3.827 - (4.467/reynolds) * log10(pow((data.roughness()/hdiameter)/7.7918, 0.9924) + (5.3326/pow(208.815+reynolds, 0.9345)))))), 2);
    qDebug() << "returning =" << re;
    return re;
}

double Colebrook::calculateDispersedFrictionFactor(Data const &data, double alpha, double reynolds, double hdiameter, double UDisp, double viscosity) const
{
    qDebug() << "Colebrook::calculateDispersedFrictionFactor()";
    qDebug() << "reynolds =" << reynolds << ", data.roughness() =" << data.roughness() << ", hdiameter =" << hdiameter;
    double re = pow(-1 / (2 * log10((data.roughness()/hdiameter)/3.7065 - (5.0272/reynolds) * log10((data.roughness()/hdiameter)/3.827 - (4.467/reynolds) * log10(pow((data.roughness()/hdiameter)/7.7918, 0.9924) + (5.3326/pow(208.815+reynolds, 0.9345)))))), 2);
    qDebug() << "returning =" << re;
    return re;
}

QString Colebrook::pluginName() const
{
    qDebug() << "Colebrook::pluginName()";
    return QString("Colebrook");
}

bool Colebrook::isLiquidWallFriction() const
{
    qDebug() << "Colebrook::isLiquidWallFriction()";
    return true;
}

bool Colebrook::isGasWallFriction() const
{
    qDebug() << "Colebrook::isGasWallFriction()";
    return true;
}

bool Colebrook::isDispersedFriction() const
{
    qDebug() << "Colebrook::isDispersedFriction()";
    return true;
}

Q_EXPORT_PLUGIN2(../../../application/MultiPhase/debug/lib/wallfriction/colebrook, Colebrook);
