/*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License as
* published by the Free Software Foundation; either version 2 of
* the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* General Public License for more details at
* http://www.gnu.org/copyleft/gpl.html
*
* Author: Marius Stene
* Email: marius.stene at gmail dot com
*
*/

#ifndef DEFAULTCALCULATEREGIMEANNULAR_H
#define DEFAULTCALCULATEREGIMEANNULAR_H

#include <QObject>
#include <QString>
#include <QtPlugin>
#include <QDebug>

#include <math.h>

#include "../../application/Support/calculateregimeinterface.h"
#include "../../application/Support/plugininterface.h"
#include "../../application/Support/frictionfunctions.h"
#include "../../application/Support/data.h"
#include "../../application/Support/calculateregimeshared.h"

class DefaultCalculateRegimeAnnular : public QObject, public CalculateRegimeInterface
{
    Q_OBJECT
    Q_INTERFACES(CalculateRegimeInterface)

public:
    DefaultCalculateRegimeAnnular();
    ~DefaultCalculateRegimeAnnular();
    
    double calculateAlpha(Data *data, FrictionFunctions *frictionFunctions, double tolerance);
    QList<QPair<QString, double> > calculate(Data *data, FrictionFunctions *frictionFunctions, double tolerance);
    double calculatePressureDrop(Data *data, FrictionFunctions *frictionFunctions, double tolerance);

    bool isAnnular() const;
    bool isDispersed() const;
    bool isStratified() const;
    bool isSlug() const;

    QString pluginName() const;
private:
    static void    frictionAnnular(Data *data, FrictionFunctions *frictionFunctions, double Usl, double Usg, double alpha,
                            double &frictionWall, double &frictionInterface, double &frictionGravityLiquid, double &frictionGravityGas);
    static double  diameterGasAnnular(Data *data, FrictionFunctions *frictionFunctions, double diameterGas, double *args, int nArg);
    static void    geometryAnnular(double alpha, double diameter, double &surfaceLiquid, double &surfaceInterface, double &thicknessFilm);
};

#endif // DEFAULTCALCULATEREGIMEANNULAR_H
