/*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License as
* published by the Free Software Foundation; either version 2 of
* the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* General Public License for more details at
* http://www.gnu.org/copyleft/gpl.html
*
* Author: Marius Stene
* Email: marius.stene at gmail dot com
*
*/

#ifndef DEFAULTCALCULATEREGIMESLUG_H
#define DEFAULTCALCULATEREGIMESLUG_H

#include <QObject>
#include <QString>
#include <QtPlugin>
#include <QDebug>

#include <math.h>

#include "../../application/Support/calculateregimeinterface.h"
#include "../../application/Support/plugininterface.h"
#include "../../application/Support/frictionfunctions.h"
#include "../../application/Support/data.h"
#include "../../application/Support/calculateregimeshared.h"

class DefaultCalculateRegimeSlug : public QObject, public CalculateRegimeInterface
{
    Q_OBJECT
    Q_INTERFACES(CalculateRegimeInterface)

public:
    DefaultCalculateRegimeSlug();
    ~DefaultCalculateRegimeSlug();
    
    double calculateAlpha(Data *data, FrictionFunctions *frictionFunctions, double tolerance);
    QList<QPair<QString, double> > calculate(Data *data, FrictionFunctions *frictionFunctions, double tolerance);
    double calculatePressureDrop(Data *data, FrictionFunctions *frictionFunctions, double tolerance);

    bool isAnnular() const;
    bool isDispersed() const;
    bool isStratified() const;
    bool isSlug() const;

    QString pluginName() const;
private:
    double          dpdxSlug(Data *data, FrictionFunctions *frictionFunctions, double alphaSlug, double alphaBubble, double UlSlug,
                               double velocityBubbleFront, double UlInBubble, double UgInBubble, double slugFraction, double slugLength,
                               double bubbleLength);
    void            slugUnit(Data *data, FrictionFunctions *frictionFunctions, double tolerance, double x,
                             double &alphaSlug, double &alphaBubble, double &UlSlug,
                             double &velocityBubbleFront,
                             double &UlInBubble, double &UgInBubble,
                             double &slugFraction, double &slugLength, double &bubbleLength);
    void            bubbleGasVelocity(Data *data, double &velocityFlow, double &velocityProduction, double &velocityBubbleFront, double &velocityBubbleNeck);
    static void     velocitiesInBubble(double alphaSlug, double alphaBubble, double UlSlug, double UgSlug, double velocityBubbleNeck,
                                       double &UlInBubble, double &UgInBubble);
    double          alphaCalc(double Usl, double Usg);
    void            slugGeometry(double diameter, double alphaSlug, double alphaBubble, double Usl, double UlInBubble, double velocityBubbleNeck,
                                 double &slugFraction, double &slugLength, double &bubbleLength);
    static double   voidBubble(Data *data, FrictionFunctions *frictionFunctions, double alphaBubble, double *args, int nArg);
    static double   interfaceAngle(double alpha);
    static void     geometry(Data *data, double angleInterface, double &surfaceLiquid, double &surfaceGas, double &surfaceInterface);

    Data *_data;
    FrictionFunctions *_frictionFunctions;
    double _tolerance;
    double _alphaSlug;
    double _alphaBubble;
    double _UlSlug;
    double _velocityBubbleFront;
    double _UlInBubble;
    double _UgInBubble;
    double _slugFraction;
    double _slugLength;
    double _bubbleLength;
};

#endif // DEFAULTCALCULATEREGIMESLUG_H
