/*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License as
* published by the Free Software Foundation; either version 2 of
* the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* General Public License for more details at
* http://www.gnu.org/copyleft/gpl.html
*
* Author: Marius Stene
* Email: marius.stene at gmail dot com
*
*/

#include "froude.h"

Froude::Froude()
{
qDebug() << "Froude::Froude()";
}

Froude::~Froude()
{
qDebug() << "Froude::~Froude()";
}

double Froude::calculateRegimeTransition(Data *data, FrictionFunctions *frictionFunctions, CalculateFunctions *calculateFunctions, double tolerance, double Usg)
{
    qDebug() << "Froude::calculateRegimeTransition()";
    double lowerbound = 0.0;
    double higherbound = 100*Usg;
    double UslTemp;
    double alphaStrat;
    double UslFroude;
    while ((higherbound - lowerbound) > tolerance) {
        UslTemp = 0.5*(lowerbound+higherbound);
        data->setUsl(UslTemp);
        alphaStrat = calculateFunctions->pluginStratified()->calculateAlpha(data, frictionFunctions, tolerance);
        UslFroude = transFroude(data, alphaStrat);
        if (UslTemp <= UslFroude) {
            lowerbound = UslTemp;
        } else {
            higherbound = UslTemp;
        }
    }
    return UslTemp;
}

regimetype_t Froude::calculateRegime(Data *data, FrictionFunctions *frictionFunctions, CalculateFunctions *calculateFunctions, double tolerance, double Usg, double Usl)
{
    double transitionUsl = calculateRegimeTransition(data, frictionFunctions, calculateFunctions, tolerance, Usg);
    if (transitionUsl > Usl) {
        return REGIME_STRATIFIED;
    } else {
        return REGIME_STRATIFIED_WAVE;
    }
}

double Froude::transFroude(Data *data, double alphaStrat)
{
    qDebug() << "Froude::transFroude()";
    double tetha = interfaceAngle(alphaStrat);
    double hL = (data->diameter()/2)*(1-cos(tetha*PI/180));
    double UslFroude = 1.5*pow((GRAVITY*hL), 0.5)*(1-alphaStrat);
    return UslFroude;
}

/** The function calculates the angle between the radii of the pipeline and the interface.
*   @param alpha Alpha value to calculate angle based on
*/
double Froude::interfaceAngle(double alpha)
{
    qDebug() << "DefaultCalculateRegimeStratified::interfaceAngle()2";
    qDebug() << "alpha = " << alpha;
    double re = PI * (1 - alpha) + pow((3*PI/2), 0.3333333333) * (1 - 2 * (1 - alpha) + pow(1-alpha, 0.3333333333) - pow(alpha, 0.3333333333));
    re = re*180/PI;
    qDebug() << "returning: " << re;
    return re;
}

QString Froude::pluginName() const
{
    qDebug() << "Froude::pluginName()";
    return QString("&Froude");
}

QString Froude::transitionDescription() const
{
    qDebug() << "Froude::transitionDescription()";
    return QString("Smooth - Wavy Stratified");
}

QString Froude::tooltip() const
{
    return QString("");
}

QString Froude::statustip() const
{
    return QString("");
}

bool Froude::transitionAnnular() const
{
    return false;
}

bool Froude::transitionStratified() const
{
    return false;
}

bool Froude::transitionDispersed() const
{
    return true;
}

bool Froude::transitionSlug() const
{
    return false;
}

Q_EXPORT_PLUGIN2(../../../application/MultiPhase/debug/lib/regimetransition/froude, Froude);
