/*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License as
* published by the Free Software Foundation; either version 2 of
* the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* General Public License for more details at
* http://www.gnu.org/copyleft/gpl.html
*
* Author: Marius Stene
* Email: marius.stene at gmail dot com
*
*/

#include "haalandextended.h"


HaalandExtendedInterfaceFriction::HaalandExtendedInterfaceFriction()
{
    qDebug() << "HaalandExtendedInterfaceFriction::HaalandExtendedInterfaceFriction()";
}

HaalandExtendedInterfaceFriction::~HaalandExtendedInterfaceFriction()
{
    qDebug() << "HaalandExtendedInterfaceFriction::~HaalandExtendedInterfaceFriction()";
}

double HaalandExtendedInterfaceFriction::calculateFrictionFactor(Data const &data, double alpha,
                double reynoldsGas, double hdiameterGas, double thicknessFilm, double frictionFactorGas) const
{
    qDebug() << "HaalandExtendedInterfaceFriction::calculateFrictionFactor()";
    //correction factor for waves on interface.
    double ug = data.Usg()/alpha;
    qDebug() << "thicknessFilm =" << thicknessFilm << ", data.surfaceTension() =" << data.surfaceTension() << ", alpha =" << alpha << ", data.viscosityGas() =" << data.viscosityGas() << "ug =" << ug;
    double k=4*thicknessFilm*pow(((1-alpha)/alpha*(data.surfaceTension()/(data.viscosityGas()*ug))), 0.5);
    //haaland friction factor
    //FIX
    //qDebug() << "reynoldsGas =" << reynoldsGas << ", hdiameterGas =" << hdiameterGas << ", k =" << k;
    double re = pow(1/(1.8*log10((6.9/reynoldsGas)+pow(k/(3.7*hdiameterGas), 1.11))), 2);
    //qDebug() << "returning: re=" << re;
    return re;
}

QString HaalandExtendedInterfaceFriction::pluginName() const
{
    qDebug() << "HaalandExtendedInterfaceFriction::pluginName()";
    return QString("Haaland Extended");
}

bool HaalandExtendedInterfaceFriction::isInterfaceFriction() const
{
    qDebug() << "HaalandExtendedInterfaceFriction::isInterfaceFriction()";
    return true;
}

Q_EXPORT_PLUGIN2(../../../application/MultiPhase/debug/lib/interfacefriction/haalandextendedinterfacefriction, HaalandExtendedInterfaceFriction);
