/*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License as
* published by the Free Software Foundation; either version 2 of
* the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* General Public License for more details at
* http://www.gnu.org/copyleft/gpl.html
*
* Author: Marius Stene
* Email: marius.stene at gmail dot com
*
*/

#include "jeffreys.h"

Jeffreys::Jeffreys()
{
qDebug() << "Jeffreys::Jeffreys()";
}

Jeffreys::~Jeffreys()
{
qDebug() << "Jeffreys::~Jeffreys()";
}

double Jeffreys::calculateRegimeTransition(Data *data, FrictionFunctions *frictionFunctions, CalculateFunctions *calculateFunctions, double tolerance, double Usg)
{
    qDebug() << "Jeffreys::calculateRegimeTransition()";
    double lowerbound = 0.0;
    double higherbound = 100*Usg;
    double UslTemp;
    double alphaStrat;
    double Ug, UgJeff;
    while ((higherbound - lowerbound) > tolerance) {
        UslTemp = 0.5*(lowerbound+higherbound);
        data->setUsl(UslTemp);
        alphaStrat = calculateFunctions->pluginStratified()->calculateAlpha(data, frictionFunctions, tolerance);
        transJeffreys(data, alphaStrat, data->Usg(), UslTemp, Ug, UgJeff);
        if (Ug <= UgJeff) {
            lowerbound = UslTemp;
        } else {
            higherbound = UslTemp;
        }
    }
    return UslTemp;
}

regimetype_t Jeffreys::calculateRegime(Data *data, FrictionFunctions *frictionFunctions, CalculateFunctions *calculateFunctions, double tolerance, double Usg, double Usl)
{
    double transitionUsl = calculateRegimeTransition(data, frictionFunctions, calculateFunctions, tolerance, Usg);
    if (transitionUsl > Usl) {
        return REGIME_STRATIFIED;
    } else {
        return REGIME_STRATIFIED_WAVE;
    }
}


void Jeffreys::transJeffreys(Data *data, double alphaStrat, double Usg, double Usl, double &Ug, double &UgJeff)
{
    qDebug() << "Jeffreys::transJeffreys()";
    Ug = Usg/alphaStrat;
    double Ul = Usl/(1-alphaStrat);
    UgJeff = pow((4*(data->viscosityLiquid()/data->densityLiquid())*(data->densityLiquid()-data->densityGas())*GRAVITY*cos(data->angleRad()))/(0.01*data->densityGas()*Ul), 0.5);
}

QString Jeffreys::pluginName() const
{
    qDebug() << "Jeffreys::pluginName()";
    return QString("&Jeffreys");
}

QString Jeffreys::transitionDescription() const
{
    qDebug() << "Jeffreys::transitionDescription()";
    return QString("Smooth - Wavy Stratified");
}

QString Jeffreys::tooltip() const
{
    return QString("");
}

QString Jeffreys::statustip() const
{
    return QString("");
}

bool Jeffreys::transitionAnnular() const
{
    return false;
}

bool Jeffreys::transitionStratified() const
{
    return false;
}

bool Jeffreys::transitionDispersed() const
{
    return true;
}

bool Jeffreys::transitionSlug() const
{
    return false;
}

Q_EXPORT_PLUGIN2(../../../application/MultiPhase/debug/lib/regimetransition/jeffreys, Jeffreys);
