/*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License as
* published by the Free Software Foundation; either version 2 of
* the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* General Public License for more details at
* http://www.gnu.org/copyleft/gpl.html
*
* Author: Marius Stene
* Email: marius.stene at gmail dot com
*
*/

#include "limitslugfraction.h"

LimitSlugFraction::LimitSlugFraction()
{
qDebug() << "LimitSlugFraction::LimitSlugFraction()";
}

LimitSlugFraction::~LimitSlugFraction()
{
qDebug() << "LimitSlugFraction::~LimitSlugFraction()";
}

double LimitSlugFraction::calculateRegimeTransition(Data *data, FrictionFunctions *frictionFunctions, CalculateFunctions *calculateFunctions, double tolerance, double Usg)
{
   // qWarning() << "LimitSlugFraction::calculateRegimeTransition()" << data;
    double lowerbound = 0.0;
    double higherbound = 100*Usg;
    double SF;
    QList<QPair<QString, double> > list;
    double UslTemp;
    double alpha;
    data->setVariable(Usg);
    while ((higherbound - lowerbound) > tolerance) {
        UslTemp = 0.5*(lowerbound+higherbound);
        data->setUsl(UslTemp);
        SF = -1;
        alpha = -1;
        list = calculateFunctions->pluginSlug()->calculate(data, frictionFunctions, tolerance);
        for (int i = 0; i < list.size(); i++) {
            if (list.at(i).first.compare("SlugFraction", Qt::CaseInsensitive) == 0) {
                SF = list.at(i).second;
            }
            if (list.at(i).first.compare("Alpha", Qt::CaseInsensitive) == 0) {
                alpha = list.at(i).second;
            }
        }

        //qWarning() << "SlugFraction = " << SF << ", alpha = " << alpha << ", UslTemp = " << UslTemp;
        if (SF == -1) {
            PluginException exp;
            exp.setWhat(QString("The regime calculation plugin '%2'' used by '%1' does not support passing SlugFraction as argument in calculate() which is required for simulation to give correct results").arg(pluginName()).arg(calculateFunctions->pluginSlug()->pluginName()));
            throw(exp);
            return -1.0;
        }
        if (SF > 1.0) {
            higherbound = UslTemp;
        } else {
            lowerbound = UslTemp;
        }
    }
    UslTemp= 0.5*(lowerbound+higherbound);
    return UslTemp;
}

regimetype_t LimitSlugFraction::calculateRegime(Data *data, FrictionFunctions *frictionFunctions, CalculateFunctions *calculateFunctions, double tolerance, double Usg, double Usl)
{
    double transitionUsl = calculateRegimeTransition(data, frictionFunctions, calculateFunctions, tolerance, Usg);
    if (transitionUsl > Usl) {
        return REGIME_SLUG;
    } else {
        return REGIME_DISPERSED;
    }
}

QString LimitSlugFraction::pluginName() const
{
    qDebug() << "LimitSlugFraction::pluginName()";
    return QString("&Limit Slug Fraction");
}

QString LimitSlugFraction::transitionDescription() const
{
    qDebug() << "LimitSlugFraction::transitionDescription()";
    return QString("Dispersed - Slug");
}

QString LimitSlugFraction::tooltip() const
{
    return QString("Limit Slug Fraction locates velocities where slug fraction (SF) is just below 1.0");
}

QString LimitSlugFraction::statustip() const
{
    return QString("Limit Slug Fraction locates velocities where slug fraction (SF) is just below 1.0");
}

bool LimitSlugFraction::transitionAnnular() const
{
    return false;
}

bool LimitSlugFraction::transitionStratified() const
{
    return false;
}

bool LimitSlugFraction::transitionDispersed() const
{
    return true;
}

bool LimitSlugFraction::transitionSlug() const
{
    return true;
}

Q_EXPORT_PLUGIN2(../../../application/MultiPhase/debug/lib/regimetransition/limitslugfraction, LimitSlugFraction);
