/*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License as
* published by the Free Software Foundation; either version 2 of
* the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* General Public License for more details at
* http://www.gnu.org/copyleft/gpl.html
*
* Author: Marius Stene
* Email: marius.stene at gmail dot com
*
*/

#include "malnes.h"


MalnesSlipRelation::MalnesSlipRelation()
{
    qDebug() << "MalnesSlipRelation::MalnesSlipRelation()";
}

MalnesSlipRelation::~MalnesSlipRelation()
{
    qDebug() << "MalnesSlipRelation::~MalnesSlipRelation()";
}


double MalnesSlipRelation::calculateLiquidVelocity(Data const &data, double Usl, double Usg, double alpha) const
{
   qDebug() << "MalnesSlipRelation::calculateLiquidVelocity()";
   double sD = slipDistribution(alpha, data.diameter(), data.slipRelationParameter());
   qDebug() << "sD=" << sD << " data.angle=" << data.angle();
   qDebug() << " data.surfaceTension=" << data.surfaceTension() << " data.densityLiquid=" << data.densityLiquid() << " data.densityGas=" << data.densityGas();
   double URel = relativeVelocityRisingBubbles(alpha, data.surfaceTension(), data.densityLiquid(), data.densityGas(), data.angle());
   qDebug() << "URel=" << URel;
   double re = ((Usg+Usl) - sD * alpha * URel) / (alpha * (sD-1) + 1);
   qDebug() << "returning=" << re;
   return re;
}

double MalnesSlipRelation::calculateGasVelocity(Data const &data, double UlDisp, double alpha) const
{
    qDebug() << "MalnesSlipRelation::calculateGasVelocity()";
    double sD = slipDistribution(alpha, data.diameter(), data.slipRelationParameter());
    qDebug() << "sD=" << sD << " data.angle=" << data.angle();
    qDebug() << " data.surfaceTension=" << data.surfaceTension() << " data.densityLiquid=" << data.densityLiquid() << " data.densityGas=" << data.densityGas();
    double URel = relativeVelocityRisingBubbles(alpha, data.surfaceTension(), data.densityLiquid(), data.densityGas(), data.angle());
    qDebug() << "URel=" << URel;
    double re = sD * (UlDisp + URel);
    qDebug() << "returning=" << re;
   return re;
}

double MalnesSlipRelation::calculateAlpha(Data const &data, double alpha, double Usl, double Usg) const
{
    qDebug() << "MalnesSlipRelation::calculateAlpha()";
    qDebug() << " data.surfaceTension=" << data.surfaceTension() << " data.densityLiquid=" << data.densityLiquid() << " data.densityGas=" << data.densityGas();
    qDebug() << " alpha=" << alpha << " Usg=" << Usg << " data.angle=" << data.angle();
    qDebug() << "Usl" << Usl << "Usg" << Usg;
    double A = pow(GRAVITY * data.surfaceTension() * (data.densityLiquid() - data.densityGas()) / pow(data.densityLiquid(), 2), 0.25);
    qDebug() << "A=" << A << "data.slipRelationParameter()" << data.slipRelationParameter();
    double re = -Usg * data.slipRelationParameter() + Usg * alpha + alpha * Usl + (alpha-pow(alpha, 2)) * 1.18 * A * pow((1-alpha)*sin(PI*data.angle()/180), 0.5);
    //double re = -Usg * 0.95 + Usg*alfa+alfa*U_sl+(alfa-alfa^2)*1.18*A*((1-alfa)*sin(data.phi))^(1/2);
    qDebug() << "returning =" << re;
    return re;
}

QString MalnesSlipRelation::pluginName() const
{
    qDebug() << "MalnesSlipRelation::pluginName()";
    return QString("Malnes");
}

bool MalnesSlipRelation::isSlipRelationFriction() const
{
    qDebug() << "MalnesSlipRelation::isSlipRelationFriction()";
    return true;
}

double MalnesSlipRelation::slipDistribution(double alpha, double diameter, double slipRelationParameter) const
{
    qDebug() << "MalnesSlipRelation::slipDistribution()";
    qDebug() << "alpha=" << alpha << " diameter=" << diameter;
    //double re = (1-alpha)/(0.95-alpha);
    double re = (1-alpha)/(slipRelationParameter-alpha);
    qDebug() << "returning=" << re;
    return re;
}

double MalnesSlipRelation::relativeVelocityRisingBubbles(double alpha, double surfaceTension, double densityLiquid, double densityGas, double angle) const
{
    qDebug() << "MalnesSlipRelation::relativeVelocityRisingBubbles()";
    qDebug() << "surfaceTension=" << surfaceTension << " densityLiquid=" << densityLiquid << " densityLiquid=" << densityLiquid << " alpha=" << alpha << " angle=" << angle;
    double re = 1.18 * pow(9.81*surfaceTension*(densityLiquid-densityGas)/pow(densityLiquid, 2), 0.25) * pow((1-alpha) * fabs(sin(PI*angle/180)), 0.5);
    qDebug() << "returning=" << re;
    return re;
}

Q_EXPORT_PLUGIN2(../../../application/MultiPhase/debug/lib/sliprelation/malnessliprelation, MalnesSlipRelation);
