/*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License as
* published by the Free Software Foundation; either version 2 of
* the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* General Public License for more details at
* http://www.gnu.org/copyleft/gpl.html
*
* Author: Marius Stene
* Email: marius.stene at gmail dot com
*
*/

#ifndef MALNES_H
#define MALNES_H

#include <QObject>
#include <QString>
#include <QtPlugin>
#include <QDebug>
#include <math.h>

#include "../../application/Support/sliprelationinterface.h"
#include "../../application/Support/plugininterface.h"
#include "../../application/Support/data.h"
#include "../../application/MultiPhase/src/defines.h"

class MalnesSlipRelation : public QObject, public SlipRelationInterface
{
    Q_OBJECT
    Q_INTERFACES(SlipRelationInterface)

public:
    MalnesSlipRelation();
    ~MalnesSlipRelation();
    double calculateLiquidVelocity(Data const &data, double Usl, double Usg, double alpha) const;
    double calculateGasVelocity(Data const &data, double UlDisp, double alpha) const;
    double calculateAlpha(Data const &data, double alpha, double Usl, double Usg) const;
    QString  pluginName() const;
    bool isSlipRelationFriction() const;
private:
    double slipDistribution(const double alpha, const double diameter, double slipRelationParameter) const;
    double relativeVelocityRisingBubbles(double alpha, double surfaceTension, double densityLiquid, double densityGas, double angle) const;
};

#endif // MALNES_H
