/*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License as
* published by the Free Software Foundation; either version 2 of
* the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* General Public License for more details at
* http://www.gnu.org/copyleft/gpl.html
*
* Author: Marius Stene
* Email: marius.stene at gmail dot com
*
*/

#include "minimumholdup.h"

MinimumHoldup::MinimumHoldup()
{
qDebug() << "MinimumHoldup::MinimumHoldup()";
}

MinimumHoldup::~MinimumHoldup()
{
qDebug() << "MinimumHoldup::~MinimumHoldup()";
}

double MinimumHoldup::calculateRegimeTransition(Data *data, FrictionFunctions *frictionFunctions, CalculateFunctions *calculateFunctions, double tolerance, double Usg)
{
    qDebug() << "MinimumHoldup::calculateRegimeTransition()";
    double lowerbound = 0.0;
    double higherbound = 100*Usg;
    double UslTemp;
    double alphaStrat, alphaAnnular;
    while ((higherbound - lowerbound) > tolerance) {
        UslTemp = 0.5*(lowerbound+higherbound);
        data->setUsl(UslTemp);
        alphaStrat = calculateFunctions->pluginStratified()->calculateAlpha(data, frictionFunctions, tolerance);
        alphaAnnular = calculateFunctions->pluginAnnular()->calculateAlpha(data, frictionFunctions, tolerance);
        if (alphaAnnular <= alphaStrat) {
            lowerbound = UslTemp;
        } else {
            higherbound = UslTemp;
        }
    }
    return UslTemp;
}

regimetype_t MinimumHoldup::calculateRegime(Data *data, FrictionFunctions *frictionFunctions, CalculateFunctions *calculateFunctions, double tolerance, double Usg, double Usl)
{
    double transitionUsl = calculateRegimeTransition(data, frictionFunctions, calculateFunctions, tolerance, Usg);
    if (transitionUsl > Usl) {
        return REGIME_STRATIFIED;
    } else {
        return REGIME_ANNULAR;
    }
}

QString MinimumHoldup::pluginName() const
{
    qDebug() << "MinimumHoldup::pluginName()";
    return QString("&Minimum Holdup (Barnea)");
}

QString MinimumHoldup::transitionDescription() const
{
    qDebug() << "MinimumHoldup::transitionDescription()";
    return QString("Stratified - Annular");
}

QString MinimumHoldup::tooltip() const
{
    return QString("Minimum Holdup locates the velocity where holdup is equal for annular and stratified flow");
}

QString MinimumHoldup::statustip() const
{
    return QString("Minimum Holdup locates the velocity where holdup is equal for annular and stratified flow");
}

bool MinimumHoldup::transitionAnnular() const
{
    return true;
}

bool MinimumHoldup::transitionStratified() const
{
    return true;
}

bool MinimumHoldup::transitionDispersed() const
{
    return false;
}

bool MinimumHoldup::transitionSlug() const
{
    return false;
}

Q_EXPORT_PLUGIN2(../../../application/MultiPhase/debug/lib/regimetransition/minimumholdup, MinimumHoldup);
