/*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License as
* published by the Free Software Foundation; either version 2 of
* the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* General Public License for more details at
* http://www.gnu.org/copyleft/gpl.html
*
* Author: Marius Stene
* Email: marius.stene at gmail dot com
*
*/

#include "radovocichmoissis.h"

RadovocichMoissis::RadovocichMoissis()
{
qDebug() << "RadovocichMoissis::RadovocichMoissis()";
}

RadovocichMoissis::~RadovocichMoissis()
{
qDebug() << "RadovocichMoissis::~RadovocichMoissis()";
}

double RadovocichMoissis::calculateRegimeTransition(Data *data, FrictionFunctions *frictionFunctions, CalculateFunctions *calculateFunctions, double tolerance, double Usg)
{
    qDebug() << "RadovocichMoissis::calculateRegimeTransition()";
    double Uo = 1.53 * pow((GRAVITY*(data->densityLiquid()-data->densityGas())*data->surfaceTension())/(pow(data->densityLiquid(), 2)), 0.25);
    double UslTemp = Usg*(1-0.25)/0.25 - (1-0.25)*Uo*sin(data->angle());
	if (UslTemp < 0)
		UslTemp = 0.001;
    return UslTemp;
}

regimetype_t RadovocichMoissis::calculateRegime(Data *data, FrictionFunctions *frictionFunctions, CalculateFunctions *calculateFunctions, double tolerance, double Usg, double Usl)
{
    double transitionUsl = calculateRegimeTransition(data, frictionFunctions, calculateFunctions, tolerance, Usg);
    if (transitionUsl > Usl) {
        return REGIME_SLUG;
    } else {
        return REGIME_DISPERSED;
    }
}

QString RadovocichMoissis::pluginName() const
{
    qDebug() << "RadovocichMoissis::pluginName()";
    return QString("&Radovicich Moissis (vertical only)");
}

QString RadovocichMoissis::transitionDescription() const
{
    qDebug() << "RadovocichMoissis::transitionDescription()";
    return QString("Dispersed - Slug");
}

QString RadovocichMoissis::tooltip() const
{
    return QString("Simular to Taitel Dukler for high liquid velocities but with correlations for pipe angle. \n\nTAITEL, Y., BARNEA, D. and DUKLER, A. E. 1980 Modeling flow pattern transitions for steady upward gas-liquid flow in vertical tubes. AIChE Jl 26, 345-354.\nN.A. Radovichich and R. Moissis, The transition from two-phase bubble flow to slug flow (Third Edition), Technical Report No. 7-7673, D.S.R., MIT, Cambridge, Massachusetts (1962).");
}

QString RadovocichMoissis::statustip() const
{
    return QString("Simular to Taitel Dukler for high liquid velocities but with correlations for pipe angle");
}

bool RadovocichMoissis::transitionAnnular() const
{
    return false;
}

bool RadovocichMoissis::transitionStratified() const
{
    return false;
}

bool RadovocichMoissis::transitionDispersed() const
{
    return true;
}

bool RadovocichMoissis::transitionSlug() const
{
    return true;
}

Q_EXPORT_PLUGIN2(../../../application/MultiPhase/debug/lib/regimetransition/radovocichmoissis, RadovocichMoissis);
