/*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License as
* published by the Free Software Foundation; either version 2 of
* the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* General Public License for more details at
* http://www.gnu.org/copyleft/gpl.html
*
* Author: Marius Stene
* Email: marius.stene at gmail dot com
*
*/

#include "taiteldukler.h"

TaitelDukler::TaitelDukler()
{
qDebug() << "TaitelDukler::TaitelDukler()";
}

TaitelDukler::~TaitelDukler()
{
qDebug() << "TaitelDukler::~TaitelDukler()";
}

double TaitelDukler::calculateRegimeTransition(Data *data, FrictionFunctions *frictionFunctions, CalculateFunctions *calculateFunctions, double tolerance, double Usg)
{
    qDebug() << "TaitelDukler::calculateRegimeTransition() ";
    double UslTemp = Usg*(1-0.52)/0.52;
    return UslTemp;
}

regimetype_t TaitelDukler::calculateRegime(Data *data, FrictionFunctions *frictionFunctions, CalculateFunctions *calculateFunctions, double tolerance, double Usg, double Usl)
{
    double transitionUsl = calculateRegimeTransition(data, frictionFunctions, calculateFunctions, tolerance, Usg);
    if (transitionUsl > Usl) {
        return REGIME_SLUG;
    } else {
        return REGIME_DISPERSED;
    }
}

QString TaitelDukler::pluginName() const
{
    qDebug() << "TaitelDukler::pluginName()";
    return QString("&Taitel Dukler");
}

QString TaitelDukler::transitionDescription() const
{
    qDebug() << "TaitelDukler::transitionDescription()";
    return QString("Dispersed - Slug");
}

QString TaitelDukler::tooltip() const
{
    return QString("Taitel Dukler for high liquid velocities.\n Usl = Usg * ((1-0.52)/0.52) \n\nTAITEL, Y., BARNEA, D. and DUKLER, A. E. 1980 Modeling flow pattern transitions for steady upward gas-liquid flow in vertical tubes. AIChE Jl 26, 345-354.");
}

QString TaitelDukler::statustip() const
{
    return QString("Taitel Dukler for high liquid velocities.\n Usl = Usg * (0.48/0.52) ");
}

bool TaitelDukler::transitionAnnular() const
{
    return false;
}

bool TaitelDukler::transitionStratified() const
{
    return false;
}

bool TaitelDukler::transitionDispersed() const
{
    return true;
}

bool TaitelDukler::transitionSlug() const
{
    return true;
}

Q_EXPORT_PLUGIN2(../../../application/MultiPhase/debug/lib/regimetransition/taiteldukler, TaitelDukler);
